==> haskell-bencode-0.6.1.1-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bencode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bencode
version:              0.6.1.1
visibility:           public
id:                   bencode-0.6.1.1-4sTdIyiC529KINs2d8G2Wi
key:                  bencode-0.6.1.1-4sTdIyiC529KINs2d8G2Wi
license:              BSD-3-Clause
copyright:
    (c) 2005-2009, David Himmelstrup,
    (c) 2006 Lemmih <lemmih@gmail.com>,
    (c) 2005 Jesper Louis Andersen <jlouis@mongers.org>

maintainer:           Peter Simons <simons@cryp.to>
author:
    Lemmih <lemmih@gmail.com>,
    Jesper Louis Andersen <jlouis@mongers.org>,
    Christopher Reichert <creichert07@gmail.com>

synopsis:             Parsers and printers for bencoded data.
description:
    Parsers and printers for bencoded data. Bencode (pronounced like B
    encode) is the encoding used by the peer-to-peer file sharing system
    BitTorrent for storing and transmitting loosely structured data.

category:             Text
abi:                  d8c051f93bbd7c39b07f3e91a0fd33ef
exposed:              True
exposed-modules:
    Data.BEncode Data.BEncode.Lexer Data.BEncode.Parser
    Data.BEncode.Reader

import-dirs:          /usr/lib/ghc-8.10.2/site-local/bencode-0.6.1.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/bencode-0.6.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/bencode-0.6.1.1
hs-libraries:         HSbencode-0.6.1.1-4sTdIyiC529KINs2d8G2Wi
depends:
    base-4.14.1.0 binary-0.8.8.0 bytestring-0.10.10.0
    containers-0.6.2.1 parsec-3.1.14.0 transformers-0.5.6.2
    transformers-compat-0.6.5-E9Rid1zC4al974cN3f5HFc

haddock-interfaces:   /usr/share/doc/haskell-bencode/html/bencode.haddock
haddock-html:         /usr/share/doc/haskell-bencode/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bencode-0.6.1.1-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bencode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bencode
version:              0.6.1.1
visibility:           public
id:                   bencode-0.6.1.1-HJSRMYPyUNIEPJrsQDwVrE
key:                  bencode-0.6.1.1-HJSRMYPyUNIEPJrsQDwVrE
license:              BSD-3-Clause
copyright:
    (c) 2005-2009, David Himmelstrup,
    (c) 2006 Lemmih <lemmih@gmail.com>,
    (c) 2005 Jesper Louis Andersen <jlouis@mongers.org>

maintainer:           Peter Simons <simons@cryp.to>
author:
    Lemmih <lemmih@gmail.com>,
    Jesper Louis Andersen <jlouis@mongers.org>,
    Christopher Reichert <creichert07@gmail.com>

synopsis:             Parsers and printers for bencoded data.
description:
    Parsers and printers for bencoded data. Bencode (pronounced like B
    encode) is the encoding used by the peer-to-peer file sharing system
    BitTorrent for storing and transmitting loosely structured data.

category:             Text
abi:                  8006eca5b4fc21312d1f6cd9f4b3cb4f
exposed:              True
exposed-modules:
    Data.BEncode Data.BEncode.Lexer Data.BEncode.Parser
    Data.BEncode.Reader

import-dirs:          /usr/lib/ghc-8.10.2/site-local/bencode-0.6.1.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/bencode-0.6.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/bencode-0.6.1.1
hs-libraries:         HSbencode-0.6.1.1-HJSRMYPyUNIEPJrsQDwVrE
depends:
    base-4.14.1.0 binary-0.8.8.0 bytestring-0.10.10.0
    containers-0.6.2.1 parsec-3.1.14.0 transformers-0.5.6.2
    transformers-compat-0.6.5-E9Rid1zC4al974cN3f5HFc

haddock-interfaces:   /usr/share/doc/haskell-bencode/html/bencode.haddock
haddock-html:         /usr/share/doc/haskell-bencode/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
